==> igniteui-react-layouts-18.7.3.tgz: package/esm2015/lib/igr-tool-action-checkbox.js <==
import { IgrToolAction } from "./igr-tool-action";
import { ToolActionCheckbox } from "./ToolActionCheckbox";
import { ensureBool, brushToString, stringToBrush } from "igniteui-react-core";
export class IgrToolActionCheckbox extends IgrToolAction {
    createImplementation() {
        return new ToolActionCheckbox();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or sets if the tool action is checked.
    */
    get isChecked() {
        return this.i.hb;
    }
    set isChecked(v) {
        this.i.hb = ensureBool(v);
    }
    /**
     * Gets or sets the background color of the checkbox when in the unchecked state.
    */
    get uncheckedBackgroundColor() {
        return brushToString(this.i.h1);
    }
    set uncheckedBackgroundColor(v) {
        this.i.h1 = stringToBrush(v);
    }
    /**
     * Gets the actual background color of the checkbox when in the unchecked state.
    */
    get actualUncheckedBackgroundColor() {
        return brushToString(this.i.hx);
    }
    set actualUncheckedBackgroundColor(v) {
        this.i.hx = stringToBrush(v);
    }
    /**
     * Gets or sets the background color of the checkbox when in the checked state.
    */
    get checkedBackgroundColor() {
        return brushToString(this.i.hz);
    }
    set checkedBackgroundColor(v) {
        this.i.hz = stringToBrush(v);
    }
    /**
     * Gets the actual background color of the checkbox when in the checked state.
    */
    get actualCheckedBackgroundColor() {
        return brushToString(this.i.hv);
    }
    set actualCheckedBackgroundColor(v) {
        this.i.hv = stringToBrush(v);
    }
    /**
     * Gets or sets the border color of the checkbox when in the unchecked state.
    */
    get uncheckedBorderColor() {
        return brushToString(this.i.h2);
    }
    set uncheckedBorderColor(v) {
        this.i.h2 = stringToBrush(v);
    }
    /**
     * Gets the actual border color of the checkbox when in the unchecked state.
    */
    get actualUncheckedBorderColor() {
        return brushToString(this.i.hy);
    }
    set actualUncheckedBorderColor(v) {
        this.i.hy = stringToBrush(v);
    }
    /**
     * Gets or sets the border color of the checkbox when in the checked state.
    */
    get checkedBorderColor() {
        return brushToString(this.i.h0);
    }
    set checkedBorderColor(v) {
        this.i.h0 = stringToBrush(v);
    }
    /**
     * Gets the actual border color of the checkbox when in the checked state.
    */
    get actualCheckedBorderColor() {
        return brushToString(this.i.hw);
    }
    set actualCheckedBorderColor(v) {
        this.i.hw = stringToBrush(v);
    }
}

==> igniteui-react-layouts-18.7.6.tgz: package/esm2015/lib/igr-tool-action-checkbox.js <==
import { IgrToolAction } from "./igr-tool-action";
import { ToolActionCheckbox } from "./ToolActionCheckbox";
import { ensureBool, brushToString, stringToBrush } from "igniteui-react-core";
export class IgrToolActionCheckbox extends IgrToolAction {
    createImplementation() {
        return new ToolActionCheckbox();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or sets if the tool action is checked.
    */
    get isChecked() {
        return this.i.g8;
    }
    set isChecked(v) {
        this.i.g8 = ensureBool(v);
    }
    /**
     * Gets or sets the background color of the checkbox when in the unchecked state.
    */
    get uncheckedBackgroundColor() {
        return brushToString(this.i.hq);
    }
    set uncheckedBackgroundColor(v) {
        this.i.hq = stringToBrush(v);
    }
    /**
     * Gets the actual background color of the checkbox when in the unchecked state.
    */
    get actualUncheckedBackgroundColor() {
        return brushToString(this.i.hm);
    }
    set actualUncheckedBackgroundColor(v) {
        this.i.hm = stringToBrush(v);
    }
    /**
     * Gets or sets the background color of the checkbox when in the checked state.
    */
    get checkedBackgroundColor() {
        return brushToString(this.i.ho);
    }
    set checkedBackgroundColor(v) {
        this.i.ho = stringToBrush(v);
    }
    /**
     * Gets the actual background color of the checkbox when in the checked state.
    */
    get actualCheckedBackgroundColor() {
        return brushToString(this.i.hk);
    }
    set actualCheckedBackgroundColor(v) {
        this.i.hk = stringToBrush(v);
    }
    /**
     * Gets or sets the border color of the checkbox when in the unchecked state.
    */
    get uncheckedBorderColor() {
        return brushToString(this.i.hr);
    }
    set uncheckedBorderColor(v) {
        this.i.hr = stringToBrush(v);
    }
    /**
     * Gets the actual border color of the checkbox when in the unchecked state.
    */
    get actualUncheckedBorderColor() {
        return brushToString(this.i.hn);
    }
    set actualUncheckedBorderColor(v) {
        this.i.hn = stringToBrush(v);
    }
    /**
     * Gets or sets the border color of the checkbox when in the checked state.
    */
    get checkedBorderColor() {
        return brushToString(this.i.hp);
    }
    set checkedBorderColor(v) {
        this.i.hp = stringToBrush(v);
    }
    /**
     * Gets the actual border color of the checkbox when in the checked state.
    */
    get actualCheckedBorderColor() {
        return brushToString(this.i.hl);
    }
    set actualCheckedBorderColor(v) {
        this.i.hl = stringToBrush(v);
    }
}
